<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
            <el-form-item label="体检号" prop="tjNum">
                <el-input v-model="queryParams.tjNum" placeholder="请输入体检号" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="客户姓名" prop="cusName">
                <el-input v-model="queryParams.cusName" placeholder="请输入客户姓名" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="登记时间" prop="registrationTime">
                <el-date-picker clearable v-model="queryParams.registrationTime" type="date" value-format="yyyy-MM-dd"
                    placeholder="请选择登记时间">
                </el-date-picker>
            </el-form-item>
            <el-form-item label="项目名" prop="proName">
                <el-input v-model="queryParams.proName" placeholder="请输入项目名" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button type="primary" plain size="mini" v-hasPermi="['hosp:detail:add']"
                    @click="handlerestore">恢复</el-button>
            </el-col>

        </el-row>

        <el-table v-loading="loading" :data="inspectionList" border @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column label="序号" align="center" prop="newID" width="55px" />
            <el-table-column label="体检号" align="center" prop="tjNum" :show-overflow-tooltip="true" />
            <!-- <el-table-column label="客户编号" align="center" prop="cusId" /> -->
            <el-table-column label="客户姓名" align="center" prop="cusName" :show-overflow-tooltip="true" />
            <el-table-column label="身份证号" align="center" prop="cusId" :show-overflow-tooltip="true" />
            <el-table-column label="项目名" align="center" prop="proName" :show-overflow-tooltip="true" />
            <el-table-column label="创建人" align="center" prop="createBy" :show-overflow-tooltip="true" />
            <el-table-column label="登记时间" align="center" prop="registrationTime" :show-overflow-tooltip="true">
                <template slot-scope="scope">
                    <span>{{ parseTime(scope.row.registrationTime, '{y}-{m}-{d}') }}</span>
                </template>
            </el-table-column>
            <el-table-column label="弃检时间" align="center" prop="createTime" width="160px" :show-overflow-tooltip="true">
                <template slot-scope="scope">
                    <span>{{ parseTime(scope.row.createTime, '{y}-{m}-{d} {hh}:{mm}:{ss}') }}</span>
                </template>
            </el-table-column>
            <el-table-column label="备注" align="center" prop="remark" :show-overflow-tooltip="true" />
            <!-- <el-table-column label="项目编号" align="center" prop="proId" /> -->

        </el-table>

        <div class="pag">
            <div class="pag1">
                <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum"
                    :limit.sync="queryParams.pageSize" @pagination="getList" />
            </div>
        </div>


    </div>
</template>

<script>
import {
    listInspection, recall
} from "@/api/hosp/inspection";

export default {
    name: "Inspection",
    data() {
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            allList: [],
            // 弃检表格数据
            inspectionList: [],

            // 是否显示弹出层
            open: false,
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                tjNum: null,
                cusName: null,
                registrationTime: null,
                proName: null
            },
            // 表单参数
            form: {},
        };
    },
    created() {
        this.getList();
    },
    methods: {
        /** 查询弃检列表 */
        getList() {
            this.loading = true;
            listInspection(this.queryParams).then(response => {
                this.inspectionList = response.rows;
                response.rows.forEach((item, index) => {
                    item.newID = (this.queryParams.pageNum - 1) * this.queryParams.pageSize + index + 1
                });
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                id: null,
                deleted: null,
                createBy: null,
                createTime: null,
                updateBy: null,
                updateTime: null,
                tjNum: null,
                cusId: null,
                cusName: null,
                registrationTime: null,
                proId: null,
                proName: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.allList = selection
            console.log(this.allList )
        },
        handlerestore() {
            recall(this.allList).then(res => {
                if(res.code == 200){
                    this.$modal.msgSuccess("已撤回成功");
                    this.getList();
                }
            })
        }
    }
};
</script>
<style scoped>
.pag {
    width: 100%;
    display: flex;
    justify-content: center;
}

.pag1 {
    width: 30%;
}
</style>
